aboutsummaryrefslogtreecommitdiff
path: root/gas/read.c
diff options
context:
space:
mode:
authorNick Clifton <nickc@redhat.com>2003-03-13 11:49:33 +0000
committerNick Clifton <nickc@redhat.com>2003-03-13 11:49:33 +0000
commit0822d0753e797b3e9e69bec809adc0500192bb40 (patch)
treebe3e1c14331e1e1e01cfe584be5976d3e81f4c6a /gas/read.c
parent053c44e1bfece752ad00adbab7a4ceb57726eb1c (diff)
downloadfsf-binutils-gdb-0822d0753e797b3e9e69bec809adc0500192bb40.zip
fsf-binutils-gdb-0822d0753e797b3e9e69bec809adc0500192bb40.tar.gz
fsf-binutils-gdb-0822d0753e797b3e9e69bec809adc0500192bb40.tar.bz2
(buffer_and_nest): Store more to sb instead of '\n'.
(get_line_sb): Return end of line character or '\n' if it is zero or non-existent.
Diffstat (limited to 'gas/read.c')
-rw-r--r--gas/read.c32
1 files changed, 16 insertions, 16 deletions
diff --git a/gas/read.c b/gas/read.c
index f8d5d7e..90ef367 100644
--- a/gas/read.c
+++ b/gas/read.c
@@ -2235,13 +2235,15 @@ s_lsym (ignore)
demand_empty_rest_of_line ();
}
-/* Read a line into an sb. */
+/* Read a line into an sb. Returns the character that ended the line
+ or zero if there are no more lines. */
static int
get_line_sb (line)
sb *line;
{
char quote1, quote2, inquote;
+ unsigned char c;
if (input_line_pointer[-1] == '\n')
bump_line_counters ();
@@ -2269,31 +2271,29 @@ get_line_sb (line)
inquote = '\0';
- while (!is_end_of_line[(unsigned char) *input_line_pointer]
- || (inquote != '\0' && *input_line_pointer != '\n'))
+ while ((c = * input_line_pointer ++) != 0
+ && (!is_end_of_line[c]
+ || (inquote != '\0' && c != '\n')))
{
- if (inquote == *input_line_pointer)
+ if (inquote == c)
inquote = '\0';
else if (inquote == '\0')
{
- if (*input_line_pointer == quote1)
+ if (c == quote1)
inquote = quote1;
- else if (*input_line_pointer == quote2)
+ else if (c == quote2)
inquote = quote2;
}
- sb_add_char (line, *input_line_pointer++);
+ sb_add_char (line, c);
}
- while (input_line_pointer < buffer_limit
- && is_end_of_line[(unsigned char) *input_line_pointer])
- {
- if (input_line_pointer[-1] == '\n')
- bump_line_counters ();
- ++input_line_pointer;
- }
-
- return 1;
+ /* Don't skip multiple end-of-line characters, because that breaks support
+ for the IA-64 stop bit (;;) which looks like two consecutive end-of-line
+ characters but isn't. Instead just skip one end of line character and
+ return the character skipped so that the caller can re-insert it if
+ necessary. */
+ return c;
}
/* Define a macro. This is an interface to macro.c. */